@@ -68,7 +68,7 @@ class Properties(CloudFormationLintRule):
                                     sub_value[2], primtype, proppath + ['Fn::If', 2]))
                     elif sub_key not in ['Fn::Base64', 'Fn::GetAtt', 'Fn::GetAZs', 'Fn::ImportValue',
                                          'Fn::Join', 'Fn::Split', 'Fn::FindInMap', 'Fn::Select', 'Ref',
-                                         'Fn::If', 'Fn::Contains', 'Fn::Sub', 'Fn::Cidr']:
+                                         'Fn::If', 'Fn::Contains', 'Fn::Sub', 'Fn::Cidr', 'Fn::Transform']:
                         message = 'Property %s has an illegal function %s' % ('/'.join(map(str, proppath)), sub_key)
                         matches.append(RuleMatch(proppath, message))
             else:
@@ -150,7 +150,7 @@ class Properties(CloudFormationLintRule):
                                 if not (resource_type == 'AWS::CloudFormation::CustomResource' or resource_type.startswith('Custom::')):
                                     message = 'Property is an object instead of List at %s' % ('/'.join(map(str, path)))
                                     matches.append(RuleMatch(path, message))
-                        else:
+                        elif not (sub_key == 'Ref' and sub_value == 'AWS::NoValue'):
                             message = 'Property is an object instead of List at %s' % ('/'.join(map(str, path)))
                             matches.append(RuleMatch(path, message))
                     else:
@@ -239,6 +239,8 @@ class Properties(CloudFormationLintRule):
                             proppath + cond_value['Path'], root))
                 elif text.is_function_returning_object():
                     self.logger.debug('Ran into function "%s".  Skipping remaining checks', prop)
+                elif len(text) == 1 and prop in 'Ref' and text.get(prop) == 'AWS::NoValue':
+                    pass
                 elif not supports_additional_properties:
                     message = 'Invalid Property %s' % ('/'.join(map(str, proppath)))
                     matches.append(RuleMatch(proppath, message))
